@@ -1317,7 +1317,9 @@ def readATLASddetHeader(filename, delimiter = '= ', useOrderedDict = False):
 #                append the values to a flattened dictionary row. Done for (e.g.) Cassandra
 #                where we have flattened data with no foreign keys. Inefficient (uses too much
 #                memory by inflating the size of each row), but effective.
-def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = None, useOrderedDict = False, appendheaderlines=False, headerdelimiter='=', headerprefix='#', headerkeycollisionsuffix='HEAD'):
+# 2022-10-10 KWS Added a rownum column. If set, each row will have an extra column name with the
+#                index offset. (Allows database inserts to be compared with source files.)
+def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = None, useOrderedDict = False, appendheaderlines=False, headerdelimiter='=', headerprefix='#', headerkeycollisionsuffix='HEAD', rownumcolumn=None):
    """readGenericDataFile.
 
    Args:
@@ -1375,7 +1377,11 @@ def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = N
    t = csv.DictReader(f, fieldnames = fieldnames, delimiter=delimiter, skipinitialspace = True)
 
    data = []
+   counter = 0
    for row in t:
+      if rownumcolumn:
+          row[rownumcolumn] = counter
+          fieldnames.append(rownumcolumn)
       if useOrderedDict:
           od = OrderedDict((key, row[key]) for key in fieldnames)
           if appendheaderlines:
@@ -1393,6 +1399,7 @@ def readGenericDataFile(filename, delimiter = ' ', skipLines = 0, fieldnames = N
                   else:
                       row[k] = v
           data.append(row)
+      counter += 1
 
    # Only close the file if we opened it in the first place
    if not (type(filename).__name__ == 'file' or type(filename).__name__ == 'instance'):
